# eric7.Preferences

Package implementing the preferences interface.

The preferences interface consists of a class, which defines the default values for all configuration items and stores the actual values. These values are read and written to the eric7 preferences file by module functions. The data is stored in a file in a subdirectory of the users home directory. The individual configuration data is accessed by accessor functions defined on the module level. The module is simply imported wherever it is needed with the statement 'import Preferences'. Do not use 'from Preferences import *' to import it.

### Packages

ConfigurationPages | Package implementing the various pages of the configuration dialog.

### Modules

ConfigurationDialog | Module implementing a dialog for the configuration of eric.
HighlightingStylesFile | Module implementing a class representing the highlighting styles JSON file.
MouseClickDialog | Module implementing a dialog for the configuration of a mouse click sequence.
PreferencesLexer | Module implementing a special QScintilla lexer to handle the preferences.
ProgramsDialog | Module implementing the Programs page.
ShortcutDialog | Module implementing a dialog for the configuration of a keyboard shortcut.
Shortcuts | Module implementing functions dealing with keyboard shortcuts.
ShortcutsDialog | Module implementing a dialog for the configuration of eric's keyboard shortcuts.
ShortcutsFile | Module implementing a class representing the shortcuts JSON file.
SubstyleDefinitionDialog | Module implementing the sub-style definition dialog.
ThemeManager | Module implementing a manager object for color themes.
ToolConfigurationDialog | Module implementing a configuration dialog for the tools menu.
ToolGroupConfigurationDialog | Module implementing a configuration dialog for the tools menu.
ViewProfileDialog | Module implementing a dialog to configure the various view profiles.
Preferences | Package implementing the preferences interface.